1.0.0 API documentation: GLM_GTX_orthonormalize

| 1.0.0 API documentation

Functions
GLM_GTX_orthonormalize
Experimental extensions

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | orthonormalize (mat< 3, 3, T, Q > const &m)
| Returns the orthonormalized matrix of m. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | orthonormalize (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
| Orthonormalizes x according y. More...

## Detailed Description

Include <glm/gtx/orthonormalize.hpp> to use the features of this extension.

Orthonormalize matrices.

## Function Documentation

## ◆ orthonormalize() [1/2]

GLM_FUNC_DECL mat<3, 3, T, Q> glm::orthonormalize | ( | mat< 3, 3, T, Q > const & | m | ) |

Returns the orthonormalized matrix of m.

See also
  GLM_GTX_orthonormalize

## ◆ orthonormalize() [2/2]

GLM_FUNC_DECL vec<3, T, Q> glm::orthonormalize | ( | vec< 3, T, Q > const & | x,
|  | vec< 3, T, Q > const & | y
| ) |  |

Orthonormalizes x according y.

See also
  GLM_GTX_orthonormalize